@@ -1762,6 +1762,20 @@ class ProgressSequence(Sequence[T]):
     
     def __do_iter__(self) -> Iterator[T]:
         yield from self._progress_func(self._iter)
+    
+    def to_list(self) -> List[T]:
+        return ListLike(self._iter, self._progress_func)
+
+
+class ListLike(List[T]):
+    def __init__(self, iterable: Iterable[T], progress_func: Callable[[Iterable[T]], Iterable[T]]) -> None:
+        super().__init__(iterable)
+        self._progress_func = progress_func
+    
+    def __iter__(self) -> Iterator[T]:
+        yield from self._progress_func(self._iter)
+    
+
 
 def throw(exception: Exception) -> None:
     raise exception
